@@ -1,5 +1,5 @@
 from graphene import Int, String
-from djraphql.util.django_models import get_field_by_name
+from djraphql.django_models import get_field_by_name
 
 
 class ModelField:
