@@ -4,6 +4,14 @@ from .schemas.default import DefaultSchema
 
 
 class SchemaBuilder(object):
+    """Entry point into the library. It is responsible for passing Entity classes
+    to the TypeRegistry instance (via register_entity_classes) and building the
+    root Query and Mutation types.
+
+    Exposes QueryRoot and MutationRoot, which should then be passed to a
+    graphene.Schema instance.
+    """
+
     def __init__(self, schema=None):
         self.schema = schema or DefaultSchema()
         self.registry = TypeRegistry(self.schema)
@@ -26,6 +34,22 @@ class SchemaBuilder(object):
     def _build_root_type(
         self, type_name, root_type_classes_key, root_type_classes_default
     ):
+        """Used to build a root type, e.g. Query or Mutation. Iterates through
+        the Entity class's root-type field as specified by root_type_classes_key
+        and checks whether the access_permissions field allows the root type to
+        exist (i.e. we don't create an insertFoo mutation for a read-only FooEntity)
+        and if so, updates the result with the fields returned by the get_root_fields
+        method of the root-type.
+
+        Args:
+            type_name: str. One of "MutationRoot" or "QueryRoot"
+            root_type_classes_key: str: One of "mutation_classes" or "query_classes"
+            root_type_classes_default: A list root type classes, which will come from
+                djraphql.schemas.default.types.queries|mutations.
+        Returns:
+            Graphene type representing the root type for GraphQL queries or mutations.
+        """
+
         attrs = {}
         for model_class in self.registry.get_available_model_classes():
             entity_class = self.registry.get_entity_class(model_class)
