@@ -1,6 +1,6 @@
 from ....abstract_type_builder import AbstractTypeBuilder, CacheableTypeBuilder
 from graphene import Field, InputObjectType
-from djraphql.util.django_models import get_pk_fields_for_model
+from djraphql.django_models import get_pk_fields_for_model
 
 
 class PkInputType(CacheableTypeBuilder, AbstractTypeBuilder):
