@@ -1,6 +1,6 @@
 from graphql.language.visitor import Visitor
 from graphene.utils.str_converters import to_snake_case
-from djraphql.util.django_models import get_field_by_name
+from djraphql.django_models import get_field_by_name
 from graphql.execution.base import get_field_def
 from graphql.execution.values import get_argument_values
 
